==> aws_cdk_aws_lambda_dotnet-0.0.5.tar.gz: aws_cdk_aws_lambda_dotnet-0.0.5/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-cdk.aws-lambda-dotnet",
    "version": "0.0.5",
    "description": "@aws-cdk/aws-lambda-dotnet",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-lambda-dotnet.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services<aws-cdk-dev@amazon.com>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws/aws-lambda-dotnet.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_lambda_dotnet",
        "aws_cdk.aws_lambda_dotnet._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_lambda_dotnet._jsii": [
            "aws-lambda-dotnet@0.0.5.jsii.tgz"
        ],
        "aws_cdk.aws_lambda_dotnet": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.8",
    "install_requires": [
        "aws-cdk-lib>=2.129.0, <3.0.0",
        "constructs>=10.0.5, <11.0.0",
        "jsii>=1.103.1, <2.0.0",
        "publication>=0.0.3",
        "typeguard>=2.13.3,<5.0.0"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Typing :: Typed",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> aws_cdk_aws_lambda_dotnet-0.0.6.tar.gz: aws_cdk_aws_lambda_dotnet-0.0.6/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-cdk.aws-lambda-dotnet",
    "version": "0.0.6",
    "description": "@aws-cdk/aws-lambda-dotnet",
    "license": "Apache-2.0",
    "url": "https://github.com/cdklabs/awscdk-lambda-dotnet.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services<aws-cdk-dev@amazon.com>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/cdklabs/awscdk-lambda-dotnet.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_lambda_dotnet",
        "aws_cdk.aws_lambda_dotnet._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_lambda_dotnet._jsii": [
            "aws-lambda-dotnet@0.0.6.jsii.tgz"
        ],
        "aws_cdk.aws_lambda_dotnet": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.8",
    "install_requires": [
        "aws-cdk-lib>=2.129.0, <3.0.0",
        "constructs>=10.0.5, <11.0.0",
        "jsii>=1.103.1, <2.0.0",
        "publication>=0.0.3",
        "typeguard>=2.13.3,<5.0.0"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Typing :: Typed",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
